@@ -1,5 +1,5 @@
 __title__ = 'starbase.client.table'
-__version__ = '0.2'
+__version__ = '0.2.4'
 __build__ = 0x000002
 __author__ = 'Artur Barseghyan'
 __all__ = ('Table',)
@@ -343,7 +343,7 @@ class Table(object):
             row_hash = base64.b64encode(row)
 
         if 1 == len(columns):
-            cf = columns.keys()[0]
+            cf = list(columns.keys())[0]
             url = "{table_name}/{row}/{cf}".format(table_name=self.name, row=row, cf=cf)
         else:
             url = "{table_name}/{row}".format(table_name=self.name, row=row_hash)
